@@ -1,7 +1,7 @@
 # Use select_vec_*() functions when user inputs column names using c()
 # Use select_dots_*() functions when user inputs column names in ...
 # _i returns the index positions
-# _chr returns a character vector
+# _chr returns a character vector (very useful for `by` arg in data.table calls)
 # _sym returns a list of symbols/expressions
 
 
@@ -25,18 +25,6 @@ select_vec_sym <- function(.df, select_vars) {
   syms(select_vec_chr(.df, {{ select_vars }}))
 }
 
-select_vec_by <- function(.df, by_vars) {
-  by_vars <- enquo(by_vars)
-
-  if(quo_is_null(by_vars)) {
-    by_vars <- NULL
-  } else {
-    by_vars <- select_vec_sym(.df, !!by_vars)
-
-    by_vars <- expr(list(!!!by_vars))
-  }
-  by_vars
-}
 
 ## dots -----------------------------------
 select_dots_i <- function(.df, ...) {
@@ -51,15 +39,30 @@ select_dots_sym <- function(.df, ...) {
   syms(select_dots_chr(.df, ...))
 }
 
-select_dots_by <- function(.df, ...) {
-  dots <- enquos(...)
+## by selectors -----------------------------------
+# deprecated for simplification - just use _chr
+# select_vec_by <- function(.df, by_vars) {
+#   by_vars <- enquo(by_vars)
+#
+#   if(quo_is_null(by_vars)) {
+#     by_vars <- NULL
+#   } else {
+#     by_vars <- select_vec_sym(.df, !!by_vars)
+#
+#     by_vars <- expr(list(!!!by_vars))
+#   }
+#   by_vars
+# }
 
-  if(length(dots) == 0) {
-    by_vars <- NULL
-  } else {
-    by_vars <- select_dots_sym(.df, ...)
-
-    by_vars <- expr(list(!!!by_vars))
-  }
-  by_vars
-}
+# select_dots_by <- function(.df, ...) {
+#   dots <- enquos(...)
+#
+#   if(length(dots) == 0) {
+#     by_vars <- NULL
+#   } else {
+#     by_vars <- select_dots_sym(.df, ...)
+#
+#     by_vars <- expr(list(!!!by_vars))
+#   }
+#   by_vars
+# }
